import { useState, useMemo, useContext, useEffect } from "react";
import { HostDetailsView } from "./HostDetailsView";
import { LinearProgress } from "@mui/material";
import { onFetchEntityError } from "../../../components/common/Helper";
import NotFoundView from "../../../components/navigation/NotFoundView/NotFoundView";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

export function HostDetailsContainer({ hostId, hostFqdn }) {
  const [error, setError] = useState(null);
  const client = useContext(apiContext);

  const statusParams = useMemo(
    () => ({
      host_id: hostId
    }),
    [hostId]
  );

  const hostParams = useMemo(
    () => ({
      fqdn: hostFqdn
    }),
    [hostFqdn]
  );

  const { value: host, error: fetchError } = useAPIMethod({
    fcn: client.apis.Hosts.findNetBoxHostByFqdn,
    params: hostParams
  });

  const { value: status, error: statusError } = useAPIMethod({
    fcn: client.apis.Hosts.findHostStatus,
    params: statusParams
  });

  useEffect(() => {
    if (fetchError || statusError) {
      const message = fetchError?.message
        ? fetchError.message
        : statusError.message;
      const status = fetchError?.status
        ? fetchError.status
        : statusError?.status;
      onFetchEntityError(message, status, setError);
    }
  }, [fetchError, statusError]);

  return (
    <>
      {error ? (
        <NotFoundView />
      ) : host && status ? (
        <HostDetailsView
          host={host}
          status={status}
          hostId={hostId}
        />
      ) : (
        <LinearProgress color="primary" />
      )}
    </>
  );
}
